API
===

.. dye_score.dye_score.DyeScore

DyeScore
--------

.. autoclass:: dye_score.dye_score.DyeScore
    :members:


.. dye_score.plotting

Plotting utils
--------------

The following plotting utils can be used directly or maybe useful template code
for reviewing your results.

.. automodule:: dye_score.plotting
    :members:
    :undoc-members:
